@@ -4,5 +4,11 @@
     Zinsert <- Z*sqrt(((x*(n-x))/n^3) + Z^2/(4*n^2))
     R.lower <- (n/(n+Z^2))*(x/n + Z^2/(2*n) - Zinsert)
     R.upper <- (n/(n+Z^2))*(x/n + Z^2/(2*n) + Zinsert)
-    data.frame(x = x, n = n, prop = x/n, conf.level = conf.level, lci = R.lower, uci = R.upper)
+    data.frame(x = x,
+               n = n,
+               proportion = x/n, 
+               lower = R.lower,
+               upper = R.upper,
+               conf.level = conf.level
+               )
 }
